==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainOffPeakWindowOptionsOffPeakWindowArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property windowStartTime 10h window for updates
 */
public data class DomainOffPeakWindowOptionsOffPeakWindowArgs(
    public val windowStartTime: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>? =
        null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs> {
    override fun toJava():
        com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs =
        com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs.builder()
            .windowStartTime(
                windowStartTime?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DomainOffPeakWindowOptionsOffPeakWindowArgs].
 */
@PulumiTagMarker
public class DomainOffPeakWindowOptionsOffPeakWindowArgsBuilder internal constructor() {
    private var windowStartTime: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>? =
        null

    /**
     * @param value 10h window for updates
     */
    @JvmName("bbdubcavjtqmjxvu")
    public suspend
    fun windowStartTime(`value`: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>) {
        this.windowStartTime = value
    }

    /**
     * @param value 10h window for updates
     */
    @JvmName("rfnblkrgdgdftnsx")
    public suspend
    fun windowStartTime(`value`: DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowStartTime = mapped
    }

    /**
     * @param argument 10h window for updates
     */
    @JvmName("psdylcxomkcymogv")
    public suspend
    fun windowStartTime(argument: suspend DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgsBuilder.() -> Unit) {
        val toBeMapped =
            DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.windowStartTime = mapped
    }

    internal fun build(): DomainOffPeakWindowOptionsOffPeakWindowArgs =
        DomainOffPeakWindowOptionsOffPeakWindowArgs(
            windowStartTime = windowStartTime,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainOffPeakWindowOptionsOffPeakWindowArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property windowStartTime 10h window for updates
 */
public data class DomainOffPeakWindowOptionsOffPeakWindowArgs(
    public val windowStartTime: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>? =
        null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs =
        com.pulumi.aws.opensearch.inputs.DomainOffPeakWindowOptionsOffPeakWindowArgs.builder()
            .windowStartTime(
                windowStartTime?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DomainOffPeakWindowOptionsOffPeakWindowArgs].
 */
@PulumiTagMarker
public class DomainOffPeakWindowOptionsOffPeakWindowArgsBuilder internal constructor() {
    private var windowStartTime: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>? =
        null

    /**
     * @param value 10h window for updates
     */
    @JvmName("napqhyvlsfwsllug")
    public suspend fun windowStartTime(`value`: Output<DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs>) {
        this.windowStartTime = value
    }

    /**
     * @param value 10h window for updates
     */
    @JvmName("fpltxcooaliyyici")
    public suspend fun windowStartTime(`value`: DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowStartTime = mapped
    }

    /**
     * @param argument 10h window for updates
     */
    @JvmName("ugowylqhpwernuom")
    public suspend fun windowStartTime(argument: suspend DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgsBuilder.() -> Unit) {
        val toBeMapped =
            DomainOffPeakWindowOptionsOffPeakWindowWindowStartTimeArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.windowStartTime = mapped
    }

    internal fun build(): DomainOffPeakWindowOptionsOffPeakWindowArgs =
        DomainOffPeakWindowOptionsOffPeakWindowArgs(
            windowStartTime = windowStartTime,
        )
}
